pub enum PortfolioError {
Show 26 variants
NotRentExempt,
OwnerMismatch,
AlreadyInUse,
UninitializedState,
InvalidInstruction,
InvalidState,
Overflow,
InvalidAmount,
InvalidTypeAccount,
ErrorWhileCreatePPU,
MaximumSPLUAdded,
MaximumADMINAdded,
MissingAdminAuthorization,
ErrorWhileAddingNewAssetToPortfolio,
ErrorWhileAddingNewSpluToUserPortfolio,
MaximumNumberOfUserWasAttended,
InvalidStateOfPPU,
InvalidStateOfTuringMachine,
InvalidStateOfPPM,
ErrorWhileUpdatingDataAccount,
ErrorFromExternalTransaction,
ErrorInvalidMint,
ErrorWhileAddingSpluSecTmpToTuringMachine,
InvalidTime,
MaximumSplmAssetsAdded,
SplmAssetNotRegistred,
}Expand description
Errors that may be returned by the Token program.
Variants
NotRentExempt
Lamport balance below rent-exempt threshold.
OwnerMismatch
Owner does not match.
AlreadyInUse
The account cannot be initialized because it is already being used.
UninitializedState
State is uninitialized.
InvalidInstruction
Invalid instruction
InvalidState
State is invalid for requested operation.
Overflow
Operation overflowed
InvalidAmount
Invalid amount, must be greater then zero
InvalidTypeAccount
Invalid type of account
ErrorWhileCreatePPU
Error while create user portfolio
MaximumSPLUAdded
Maximum number of splu attended
MaximumADMINAdded
Maximum number of admins attended
MissingAdminAuthorization
Missing admin authorization
ErrorWhileAddingNewAssetToPortfolio
Error while adding new asset to portfolio
ErrorWhileAddingNewSpluToUserPortfolio
Error while adding new splu to user portfolio
MaximumNumberOfUserWasAttended
Error while adding new ppu to distribute account
InvalidStateOfPPU
Error invalid state of user account
InvalidStateOfTuringMachine
Error invalid state of turing machine account
InvalidStateOfPPM
Error invalid state of portfolio account
ErrorWhileUpdatingDataAccount
Error while updating data account
ErrorFromExternalTransaction
Error while executing external transaction
ErrorInvalidMint
Error invalid mint
ErrorWhileAddingSpluSecTmpToTuringMachine
Error while adding splu secondary temporal to turing machine
InvalidTime
Error invalid time
MaximumSplmAssetsAdded
Maximum number of splm assets attended
SplmAssetNotRegistred
splm asset not registred